==> nl-2.2.zip: nl/main.lang.php <==
<?php
# -- BEGIN LICENSE BLOCK ---------------------------------------
#
# This file is part of Dotclear 2.
#
# Copyright (c) 2003-2010 Olivier Meunier & Association Dotclear
# Licensed under the GPL version 2.0 license.
# See LICENSE file or
# http://www.gnu.org/licenses/old-licenses/gpl-2.0.html
#
# -- END LICENSE BLOCK -----------------------------------------#
#
#
#        DOT NOT MODIFY THIS FILE !




$GLOBALS['__l10n']['Dotclear has been upgraded.'] = 'Dotclear is geupgrade.';
$GLOBALS['__l10n']['Password reset'] = 'Wachtwoord gewijzigd';
$GLOBALS['__l10n']['Someone has requested to reset the password for the following site and username.'] = 'Iemand heeft een wijziging van het wachtwoord voor de volgende site en gebruikersnaam aangevraagd.';
$GLOBALS['__l10n']['Username:'] = 'Gebruikersnaam:';
$GLOBALS['__l10n']['To reset your password visit the following address, otherwise just ignore this email and nothing will happen.'] = 'Om je wachtwoord te wijzigen, ga naar het volgende adres, als je wachtwoord niet wil wijzigen, vergeet deze email.';
$GLOBALS['__l10n']['The e-mail was sent successfully to %s.'] = 'De e-mail is succesvol verzonden naar %s.';
$GLOBALS['__l10n']['Your new password'] = 'Je nieuwe wachtwoord';
$GLOBALS['__l10n']['Password:'] = 'Wachtwoord:';
$GLOBALS['__l10n']['Your new password is in your mailbox.'] = 'Je nieuwe wachtwoord staat in je mailbox';
$GLOBALS['__l10n']['Passwords don\'t match'] = 'Wachtwoorden komen niet overeen';
$GLOBALS['__l10n']['You didn\'t change your password.'] = 'Je hebt je wachtwoord niet gewijzigd.';
$GLOBALS['__l10n']['You have to change your password before you can login.'] = 'Je moet je wachtwoord wijzigen';
$GLOBALS['__l10n']['In order to login, you have to change your password now.'] = 'Om in te loggen moet je nu je wachtwoord veranderen.';
$GLOBALS['__l10n']['Wrong username or password'] = 'Verkeerde gebruikersnaam of wachtwoord';
$GLOBALS['__l10n']['Back to login screen'] = 'Terug naar het login scherm';
$GLOBALS['__l10n']['Request a new password'] = 'Vraag een nieuw wachtwoord aan';
$GLOBALS['__l10n']['Email:'] = 'Email:';
$GLOBALS['__l10n']['recover'] = 'terughalen';
$GLOBALS['__l10n']['Change your password'] = 'Verander je wachtwoord';
$GLOBALS['__l10n']['New password:'] = 'Nieuw wachtwoord:';
$GLOBALS['__l10n']['Confirm password:'] = 'Bevestig wachtwoord:';
$GLOBALS['__l10n']['change'] = 'verander';
$GLOBALS['__l10n']['Remember my ID on this computer'] = 'Onthoud mijn ID op deze computer';
$GLOBALS['__l10n']['login'] = 'login';
$GLOBALS['__l10n']['You must accept cookies in order to use the private area.'] = 'Je moet cookies accepteren om deze pagina te bekijken.';
$GLOBALS['__l10n']['I forgot my password'] = 'Ik ben mijn wachtwoord vergeten.';
$GLOBALS['__l10n']['New blog'] = 'Niewe blog';
$GLOBALS['__l10n']['Blogs'] = 'Blogs';
$GLOBALS['__l10n']['Blog details'] = 'Blog details';
$GLOBALS['__l10n']['Blog ID:'] = 'Blog ID:';
$GLOBALS['__l10n']['Required field'] = 'Verplicht veld';
$GLOBALS['__l10n']['At least 2 characters using letters, numbers or symbols.'] = 'Minimaal 2 karakter gebruiken.';
$GLOBALS['__l10n']['Please note that changing your blog ID may require changes in your public index.php file.'] = 'Bij het veranderen van je blog ID moet je misschien iets wijzigen in je index.php bestand.';
$GLOBALS['__l10n']['Blog name:'] = 'Naam van blog:';
$GLOBALS['__l10n']['Blog URL:'] = 'Blog URL:';
$GLOBALS['__l10n']['Blog description:'] = 'Blog beschrijving:';
$GLOBALS['__l10n']['save'] = 'opslaan';
$GLOBALS['__l10n']['No such blog ID'] = 'Die blog ID bestaat niet.';
$GLOBALS['__l10n']['Password verification failed'] = 'Wachtwoord verificatie mislukt';
$GLOBALS['__l10n']['Delete a blog'] = 'Verwijder een blog';
$GLOBALS['__l10n']['Warning'] = 'Waarschuwing';
$GLOBALS['__l10n']['You are about to delete the blog %s. Every entry, comment and category will be deleted.'] = 'Je gaat blog %s verwijderen. Alle posts, comments en categorïen worden verwijdered.';
$GLOBALS['__l10n']['Please give your password to confirm the blog deletion.'] = 'Voer alsjeblieft je wachtwoord in om de verwijdering van het blog te bevestigen,';
$GLOBALS['__l10n']['Your password:'] = 'Je wachtwoord:';
$GLOBALS['__l10n']['Delete this blog'] = 'Verwijder dit blog';
$GLOBALS['__l10n']['No given blog id.'] = 'Geen blog id gegeven.';
$GLOBALS['__l10n']['No such blog.'] = 'Die blog bestaat niet.';
$GLOBALS['__l10n']['year/month/day/title'] = 'jaar/maand/dag/titel';
$GLOBALS['__l10n']['year/month/title'] = 'jaar/maand/titel';
$GLOBALS['__l10n']['year/title'] = 'jaar/titel';
$GLOBALS['__l10n']['title'] = 'titel';
$GLOBALS['__l10n']['Title'] = 'Titel';
$GLOBALS['__l10n']['Title, Date'] = 'Titel, datum';
$GLOBALS['__l10n']['Title, Country, Date'] = 'Titel, land, datum';
$GLOBALS['__l10n']['Title, City, Country, Date'] = 'Titel, stad, land, datum';
$GLOBALS['__l10n']['I would like search engines and archivers to index and archive my blog\'s content.'] = 'Zoekmachines mogen mijn blog indexeren en archiveren.';
$GLOBALS['__l10n']['I would like search engines and archivers to index but not archive my blog\'s content.'] = 'Zoekmachines mogen mijn blog indexeren, maar niet archiveren.';
$GLOBALS['__l10n']['I would like to prevent search engines and archivers from indexing or archiving my blog\'s content.'] = 'Zoekmachines mogen mijn blog niet indexeren en archiveren.';
$GLOBALS['__l10n']['Invalid language code'] = 'Verkeerde taal code';
$GLOBALS['__l10n']['Blog settings'] = 'Blog instellingen';
$GLOBALS['__l10n']['Blog has been successfully created.'] = 'Blog succesvol gemaakt.';
$GLOBALS['__l10n']['Blog has been successfully updated.'] = 'Blog succesvol geupdate.';
$GLOBALS['__l10n']['Parameters'] = 'Parameters';
$GLOBALS['__l10n']['URL scan method:'] = 'URL scan methode:';
$GLOBALS['__l10n']['Blog status:'] = 'Blog status:';
$GLOBALS['__l10n']['Blog configuration'] = 'Blog configuratie';
$GLOBALS['__l10n']['Blog editor name:'] = 'Naam van de auteur van de blog:';
$GLOBALS['__l10n']['Default language:'] = 'Standaard taal:';
$GLOBALS['__l10n']['Blog timezone:'] = 'Tijdzone van blog:';
$GLOBALS['__l10n']['Copyright notice:'] = 'Copyright tekst:';
$GLOBALS['__l10n']['New post URL format:'] = 'URL formaat:';
$GLOBALS['__l10n']['Enable XML/RPC interface'] = 'Accepter XML/RPC interface';
$GLOBALS['__l10n']['more information'] = 'meer informatie';
$GLOBALS['__l10n']['Comments and trackbacks'] = 'Comments en trackbacks';
$GLOBALS['__l10n']['Accept comments'] = 'Accepteer comments';
$GLOBALS['__l10n']['Moderate comments'] = 'Beheer comments';
$GLOBALS['__l10n']['Leave comments open for %s days'] = 'Mensen kunnen reageren voor %s dagen';
$GLOBALS['__l10n']['Leave blank to disable this feature.'] = 'Laat leeg om deze optie niet toe te passsen';
$GLOBALS['__l10n']['Wiki syntax for comments'] = 'Wiki syntax voor comments';
$GLOBALS['__l10n']['Accept trackbacks'] = 'Accepteer trackbacks';
$GLOBALS['__l10n']['Moderate trackbacks'] = 'Beheer trackbacks';
$GLOBALS['__l10n']['Leave trackbacks open for %s days'] = 'Laat trackbacks open voor %s dagen.';
$GLOBALS['__l10n']['Add "nofollow" relation on comments and trackbacks links'] = 'Add "nofollow" relation on comments and trackbacks links';
$GLOBALS['__l10n']['Blog presentation'] = 'Blog presentatie';
$GLOBALS['__l10n']['Date format:'] = 'Datum formaat:';
$GLOBALS['__l10n']['Time format:'] = 'Tijd formaat:';
$GLOBALS['__l10n']['Display smilies on entries and comments'] = 'Geef smilies weer bij posts en bomments';
$GLOBALS['__l10n']['Display %s entries per page'] = 'Geef %s posts weer per pagina';
$GLOBALS['__l10n']['Display %s entries per feed'] = 'Geef %s posts weer per feed';
$GLOBALS['__l10n']['Display %s comments per feed'] = 'Geef %s comments weer per feed';
$GLOBALS['__l10n']['Truncate feeds'] = 'Verklein feeds';
$GLOBALS['__l10n']['Media and images'] = 'Media en afbeeldingen';
$GLOBALS['__l10n']['Generated image sizes (in pixels)'] = 'Gegenereede afbeeldinggrootte in pixels';
$GLOBALS['__l10n']['Thumbnails:'] = 'Miniaturen';
$GLOBALS['__l10n']['Small:'] = 'Klein:';
$GLOBALS['__l10n']['Medium:'] = 'Medium:';
$GLOBALS['__l10n']['Inserted image title'] = 'Afbeelding titel ingevoerd';
$GLOBALS['__l10n']['This defines image tag title when you insert it in a post from the media manager. It is retrieved from the picture\'s metadata.'] = 'Dit stelt de afbeeldingtag in wanneer je het invoegt in een post vanaf de media manager. Hij word gehaald van de metadata van de afbeelding.';
$GLOBALS['__l10n']['Search engines robots policy'] = 'Zoekmachine robot instellingen';
$GLOBALS['__l10n']['XML/RPC interface'] = 'XML/RPC interface';
$GLOBALS['__l10n']['XML/RPC interface allows you to edit your blog with an external client.'] = 'Met deXML/RPC interface kun je je blog bewerken via een externe verbinding.';
$GLOBALS['__l10n']['XML/RPC interface is not active. Change settings to enable it.'] = 'XML/RPC interface is inactief. Verander de instellingen om het actief te maken.';
$GLOBALS['__l10n']['XML/RPC interface is active. You should set the following parameters on your XML/RPC client:'] = 'XMl/RPC interface is actief. Je moet de volgende parameter in je XML/RPX client instellen:';
$GLOBALS['__l10n']['Server URL:'] = 'Server URL:';
$GLOBALS['__l10n']['Blogging system:'] = 'Blogsysteem:';
$GLOBALS['__l10n']['User name:'] = 'Gebruikersnaam:';
$GLOBALS['__l10n']['your password'] = 'je wachtwoord';
$GLOBALS['__l10n']['Users'] = 'Gebruikers';
$GLOBALS['__l10n']['Users on this blog'] = 'Gebruikers op deze blog';
$GLOBALS['__l10n']['No users'] = 'Geen gebruikers';
$GLOBALS['__l10n']['change permissions'] = 'verander toestemmingen';
$GLOBALS['__l10n']['Super administrator'] = 'Super administrator';
$GLOBALS['__l10n']['You can\'t remove default theme.'] = 'Je kan het standaard thema niet verwijderen.';
$GLOBALS['__l10n']['Theme does not exist.'] = 'Thema bestaat niet.';
$GLOBALS['__l10n']['Unable to move uploaded file.'] = 'Kan het gëuploade bestand niet verplaatsen.';
$GLOBALS['__l10n']['An error occurred while downloading the file.'] = 'Er was een error toen het bestand gedownload werd.';
$GLOBALS['__l10n']['by %s'] = 'door %s';
$GLOBALS['__l10n']['version %s'] = 'versie %s';
$GLOBALS['__l10n']['(built on "%s")'] = '(gemaakt met "%s")';
$GLOBALS['__l10n']['(requires "%s")'] = '("%s" nodig)';
$GLOBALS['__l10n']['Stylesheet'] = 'Stylesheet';
$GLOBALS['__l10n']['Theme configuration'] = 'Thema instellingen';
$GLOBALS['__l10n']['Blog themes'] = 'Blog instellingen';
$GLOBALS['__l10n']['Blog appearance'] = 'Blog aanzien';
$GLOBALS['__l10n']['Theme has been successfully changed.'] = 'Thema\'s succesvol gewijzigd.';
$GLOBALS['__l10n']['Theme has been successfully installed.'] = 'Thema succesvol geinstalleerd.';
$GLOBALS['__l10n']['Theme has been successfully upgraded'] = 'Thema succesvol geupgrade';
$GLOBALS['__l10n']['Theme has been successfully deleted.'] = 'Thema succesvol verwijderd.';
$GLOBALS['__l10n']['You can find additional themes for your blog on %s.'] = 'Je kan andere thema\'s voor je blog vinden op %s.';
$GLOBALS['__l10n']['To install or upgrade a theme you generally just need to upload it in "Install or upgrade a theme" section.'] = 'Om een thema te installeren of te upgraden, moet je het uploaden in de "Installeer of upgrade een theme" sectie.';
$GLOBALS['__l10n']['Themes'] = 'Thema\'s';
$GLOBALS['__l10n']['You are currently using "%s"'] = 'Je gebruikt nu "%s"';
$GLOBALS['__l10n']['use selected theme'] = 'gebruik geselecteerd thema';
$GLOBALS['__l10n']['delete selected theme'] = 'verwijder geselecteerd thema';
$GLOBALS['__l10n']['Install or upgrade a theme'] = 'Installeer of upgrade een thema.';
$GLOBALS['__l10n']['You can install themes by uploading or downloading zip files.'] = 'Je kan thema\'s instelleren door de zip-files te up- of downloaden.';
$GLOBALS['__l10n']['Upload a zip file'] = 'Upload een zip file';
$GLOBALS['__l10n']['Theme zip file:'] = 'Thema zip file:';
$GLOBALS['__l10n']['Upload theme'] = 'Upload thema';
$GLOBALS['__l10n']['superadmin'] = 'Super administrator';
?>

==> nl-2.3.0.zip: nl/main.lang.php <==
<?php
# -- BEGIN LICENSE BLOCK ---------------------------------------
#
# This file is part of Dotclear 2.
#
# Copyright (c) 2003-2011 Olivier Meunier & Association Dotclear
# Licensed under the GPL version 2.0 license.
# See LICENSE file or
# http://www.gnu.org/licenses/old-licenses/gpl-2.0.html
#
# -- END LICENSE BLOCK -----------------------------------------#
#
#
#        DOT NOT MODIFY THIS FILE !




$GLOBALS['__l10n']['Dotclear has been upgraded.'] = 'Dotclear is geupgrade.';
$GLOBALS['__l10n']['Password reset'] = 'Wachtwoord gewijzigd';
$GLOBALS['__l10n']['Someone has requested to reset the password for the following site and username.'] = 'Iemand heeft een wijziging van het wachtwoord voor de volgende site en gebruikersnaam aangevraagd.';
$GLOBALS['__l10n']['Username:'] = 'Gebruikersnaam:';
$GLOBALS['__l10n']['To reset your password visit the following address, otherwise just ignore this email and nothing will happen.'] = 'Om je wachtwoord te wijzigen, ga naar het volgende adres, als je wachtwoord niet wil wijzigen, vergeet deze email.';
$GLOBALS['__l10n']['The e-mail was sent successfully to %s.'] = 'De e-mail is succesvol verzonden naar %s.';
$GLOBALS['__l10n']['Your new password'] = 'Je nieuwe wachtwoord';
$GLOBALS['__l10n']['Password:'] = 'Wachtwoord:';
$GLOBALS['__l10n']['Your new password is in your mailbox.'] = 'Je nieuwe wachtwoord staat in je mailbox';
$GLOBALS['__l10n']['Passwords don\'t match'] = 'Wachtwoorden komen niet overeen';
$GLOBALS['__l10n']['You didn\'t change your password.'] = 'Je hebt je wachtwoord niet gewijzigd.';
$GLOBALS['__l10n']['You have to change your password before you can login.'] = 'Je moet je wachtwoord wijzigen';
$GLOBALS['__l10n']['In order to login, you have to change your password now.'] = 'Om in te loggen moet je nu je wachtwoord veranderen.';
$GLOBALS['__l10n']['Wrong username or password'] = 'Verkeerde gebruikersnaam of wachtwoord';
$GLOBALS['__l10n']['Back to login screen'] = 'Terug naar het login scherm';
$GLOBALS['__l10n']['Request a new password'] = 'Vraag een nieuw wachtwoord aan';
$GLOBALS['__l10n']['Email:'] = 'Email:';
$GLOBALS['__l10n']['recover'] = 'terughalen';
$GLOBALS['__l10n']['Change your password'] = 'Verander je wachtwoord';
$GLOBALS['__l10n']['New password:'] = 'Nieuw wachtwoord:';
$GLOBALS['__l10n']['Confirm password:'] = 'Bevestig wachtwoord:';
$GLOBALS['__l10n']['change'] = 'verander';
$GLOBALS['__l10n']['Remember my ID on this computer'] = 'Onthoud mijn ID op deze computer';
$GLOBALS['__l10n']['log in'] = 'Blog instellingen';
$GLOBALS['__l10n']['You must accept cookies in order to use the private area.'] = 'Je moet cookies accepteren om deze pagina te bekijken.';
$GLOBALS['__l10n']['I forgot my password'] = 'Ik ben mijn wachtwoord vergeten.';
$GLOBALS['__l10n']['New blog'] = 'Niewe blog';
$GLOBALS['__l10n']['Blogs'] = 'Blogs';
$GLOBALS['__l10n']['Blog details'] = 'Blog details';
$GLOBALS['__l10n']['Blog ID:'] = 'Blog ID:';
$GLOBALS['__l10n']['Required field'] = 'Verplicht veld';
$GLOBALS['__l10n']['At least 2 characters using letters, numbers or symbols.'] = 'Minimaal 2 karakter gebruiken.';
$GLOBALS['__l10n']['Please note that changing your blog ID may require changes in your public index.php file.'] = 'Bij het veranderen van je blog ID moet je misschien iets wijzigen in je index.php bestand.';
$GLOBALS['__l10n']['Blog name:'] = 'Naam van blog:';
$GLOBALS['__l10n']['Blog URL:'] = 'Blog URL:';
$GLOBALS['__l10n']['Blog description:'] = 'Blog beschrijving:';
$GLOBALS['__l10n']['No such blog ID'] = 'Die blog ID bestaat niet.';
$GLOBALS['__l10n']['Password verification failed'] = 'Wachtwoord verificatie mislukt';
$GLOBALS['__l10n']['Delete a blog'] = 'Verwijder een blog';
$GLOBALS['__l10n']['Warning'] = 'Waarschuwing';
$GLOBALS['__l10n']['You are about to delete the blog %s. Every entry, comment and category will be deleted.'] = 'Je gaat blog %s verwijderen. Alle posts, comments en categorïen worden verwijdered.';
$GLOBALS['__l10n']['Please give your password to confirm the blog deletion.'] = 'Voer alsjeblieft je wachtwoord in om de verwijdering van het blog te bevestigen,';
$GLOBALS['__l10n']['Your password:'] = 'Je wachtwoord:';
$GLOBALS['__l10n']['Delete this blog'] = 'Verwijder dit blog';
$GLOBALS['__l10n']['No given blog id.'] = 'Geen blog id gegeven.';
$GLOBALS['__l10n']['No such blog.'] = 'Die blog bestaat niet.';
$GLOBALS['__l10n']['year/month/day/title'] = 'jaar/maand/dag/titel';
$GLOBALS['__l10n']['year/month/title'] = 'jaar/maand/titel';
$GLOBALS['__l10n']['year/title'] = 'jaar/titel';
$GLOBALS['__l10n']['title'] = 'titel';
$GLOBALS['__l10n']['Title'] = 'Titel';
$GLOBALS['__l10n']['Title, Date'] = 'Titel, datum';
$GLOBALS['__l10n']['Title, Country, Date'] = 'Titel, land, datum';
$GLOBALS['__l10n']['Title, City, Country, Date'] = 'Titel, stad, land, datum';
$GLOBALS['__l10n']['I would like search engines and archivers to index and archive my blog\'s content.'] = 'Zoekmachines mogen mijn blog indexeren en archiveren.';
$GLOBALS['__l10n']['I would like search engines and archivers to index but not archive my blog\'s content.'] = 'Zoekmachines mogen mijn blog indexeren, maar niet archiveren.';
$GLOBALS['__l10n']['I would like to prevent search engines and archivers from indexing or archiving my blog\'s content.'] = 'Zoekmachines mogen mijn blog niet indexeren en archiveren.';
$GLOBALS['__l10n']['Invalid language code'] = 'Verkeerde taal code';
$GLOBALS['__l10n']['Blog settings'] = 'Blog instellingen';
$GLOBALS['__l10n']['Blog has been successfully created.'] = 'Blog succesvol gemaakt.';
$GLOBALS['__l10n']['Blog has been successfully updated.'] = 'Blog succesvol geupdate.';
$GLOBALS['__l10n']['Parameters'] = 'Parameters';
$GLOBALS['__l10n']['URL scan method:'] = 'URL scan methode:';
$GLOBALS['__l10n']['Blog status:'] = 'Blog status:';
$GLOBALS['__l10n']['Blog configuration'] = 'Blog configuratie';
$GLOBALS['__l10n']['Blog editor name:'] = 'Naam van de auteur van de blog:';
$GLOBALS['__l10n']['Default language:'] = 'Standaard taal:';
$GLOBALS['__l10n']['Blog timezone:'] = 'Tijdzone van blog:';
$GLOBALS['__l10n']['Copyright notice:'] = 'Copyright tekst:';
$GLOBALS['__l10n']['New post URL format:'] = 'URL formaat:';
$GLOBALS['__l10n']['Enable XML/RPC interface'] = 'Accepter XML/RPC interface';
$GLOBALS['__l10n']['more information'] = 'meer informatie';
$GLOBALS['__l10n']['Comments and trackbacks'] = 'Comments en trackbacks';
$GLOBALS['__l10n']['Accept comments'] = 'Accepteer comments';
$GLOBALS['__l10n']['Moderate comments'] = 'Beheer comments';
$GLOBALS['__l10n']['Leave comments open for %s days'] = 'Mensen kunnen reageren voor %s dagen';
$GLOBALS['__l10n']['Leave blank to disable this feature.'] = 'Laat leeg om deze optie niet toe te passsen';
$GLOBALS['__l10n']['Wiki syntax for comments'] = 'Wiki syntax voor comments';
$GLOBALS['__l10n']['Accept trackbacks'] = 'Accepteer trackbacks';
$GLOBALS['__l10n']['Moderate trackbacks'] = 'Beheer trackbacks';
$GLOBALS['__l10n']['Leave trackbacks open for %s days'] = 'Laat trackbacks open voor %s dagen.';
$GLOBALS['__l10n']['Add "nofollow" relation on comments and trackbacks links'] = 'Add "nofollow" relation on comments and trackbacks links';
$GLOBALS['__l10n']['Blog presentation'] = 'Blog presentatie';
$GLOBALS['__l10n']['Date format:'] = 'Datum formaat:';
$GLOBALS['__l10n']['Time format:'] = 'Tijd formaat:';
$GLOBALS['__l10n']['Display smilies on entries and comments'] = 'Geef smilies weer bij posts en bomments';
$GLOBALS['__l10n']['Display %s entries per page'] = 'Geef %s posts weer per pagina';
$GLOBALS['__l10n']['Display %s entries per feed'] = 'Geef %s posts weer per feed';
$GLOBALS['__l10n']['Display %s comments per feed'] = 'Geef %s comments weer per feed';
$GLOBALS['__l10n']['Truncate feeds'] = 'Verklein feeds';
$GLOBALS['__l10n']['Media and images'] = 'Media en afbeeldingen';
$GLOBALS['__l10n']['Generated image sizes (in pixels)'] = 'Gegenereede afbeeldinggrootte in pixels';
$GLOBALS['__l10n']['Thumbnails:'] = 'Miniaturen';
$GLOBALS['__l10n']['Small:'] = 'Klein:';
$GLOBALS['__l10n']['Medium:'] = 'Medium:';
$GLOBALS['__l10n']['Inserted image title'] = 'Afbeelding titel ingevoerd';
$GLOBALS['__l10n']['This defines image tag title when you insert it in a post from the media manager. It is retrieved from the picture\'s metadata.'] = 'Dit stelt de afbeeldingtag in wanneer je het invoegt in een post vanaf de media manager. Hij word gehaald van de metadata van de afbeelding.';
$GLOBALS['__l10n']['Search engines robots policy'] = 'Zoekmachine robot instellingen';
$GLOBALS['__l10n']['XML/RPC interface'] = 'XML/RPC interface';
$GLOBALS['__l10n']['XML/RPC interface allows you to edit your blog with an external client.'] = 'Met deXML/RPC interface kun je je blog bewerken via een externe verbinding.';
$GLOBALS['__l10n']['XML/RPC interface is not active. Change settings to enable it.'] = 'XML/RPC interface is inactief. Verander de instellingen om het actief te maken.';
$GLOBALS['__l10n']['XML/RPC interface is active. You should set the following parameters on your XML/RPC client:'] = 'XMl/RPC interface is actief. Je moet de volgende parameter in je XML/RPX client instellen:';
$GLOBALS['__l10n']['Server URL:'] = 'Server URL:';
$GLOBALS['__l10n']['Blogging system:'] = 'Blogsysteem:';
$GLOBALS['__l10n']['User name:'] = 'Gebruikersnaam:';
$GLOBALS['__l10n']['your password'] = 'je wachtwoord';
$GLOBALS['__l10n']['Users'] = 'Gebruikers';
$GLOBALS['__l10n']['Users on this blog'] = 'Gebruikers op deze blog';
$GLOBALS['__l10n']['No users'] = 'Geen gebruikers';
$GLOBALS['__l10n']['change permissions'] = 'verander toestemmingen';
$GLOBALS['__l10n']['Super administrator'] = 'Super administrator';
$GLOBALS['__l10n']['You can\'t remove default theme.'] = 'Je kan het standaard thema niet verwijderen.';
$GLOBALS['__l10n']['Theme does not exist.'] = 'Thema bestaat niet.';
$GLOBALS['__l10n']['Unable to move uploaded file.'] = 'Kan het gëuploade bestand niet verplaatsen.';
$GLOBALS['__l10n']['An error occurred while downloading the file.'] = 'Er was een error toen het bestand gedownload werd.';
$GLOBALS['__l10n']['by %s'] = 'door %s';
$GLOBALS['__l10n']['version %s'] = 'versie %s';
$GLOBALS['__l10n']['(built on "%s")'] = '(gemaakt met "%s")';
$GLOBALS['__l10n']['(requires "%s")'] = '("%s" nodig)';
$GLOBALS['__l10n']['Stylesheet'] = 'Stylesheet';
$GLOBALS['__l10n']['Theme configuration'] = 'Thema instellingen';
$GLOBALS['__l10n']['Blog themes'] = 'Blog instellingen';
$GLOBALS['__l10n']['Blog appearance'] = 'Blog aanzien';
$GLOBALS['__l10n']['Theme has been successfully changed.'] = 'Thema\'s succesvol gewijzigd.';
$GLOBALS['__l10n']['Theme has been successfully installed.'] = 'Thema succesvol geinstalleerd.';
$GLOBALS['__l10n']['Theme has been successfully upgraded'] = 'Thema succesvol geupgrade';
$GLOBALS['__l10n']['Theme has been successfully deleted.'] = 'Thema succesvol verwijderd.';
$GLOBALS['__l10n']['You can find additional themes for your blog on %s.'] = 'Je kan andere thema\'s voor je blog vinden op %s.';
$GLOBALS['__l10n']['To install or upgrade a theme you generally just need to upload it in "Install or upgrade a theme" section.'] = 'Om een thema te installeren of te upgraden, moet je het uploaden in de "Installeer of upgrade een theme" sectie.';
$GLOBALS['__l10n']['Themes'] = 'Thema\'s';
$GLOBALS['__l10n']['You are currently using "%s"'] = 'Je gebruikt nu "%s"';
$GLOBALS['__l10n']['use selected theme'] = 'gebruik geselecteerd thema';
$GLOBALS['__l10n']['delete selected theme'] = 'verwijder geselecteerd thema';
$GLOBALS['__l10n']['Install or upgrade a theme'] = 'Installeer of upgrade een thema.';
$GLOBALS['__l10n']['You can install themes by uploading or downloading zip files.'] = 'Je kan thema\'s instelleren door de zip-files te up- of downloaden.';
$GLOBALS['__l10n']['Upload a zip file'] = 'Upload een zip file';
$GLOBALS['__l10n']['Theme zip file:'] = 'Thema zip file:';
$GLOBALS['__l10n']['Upload theme'] = 'Upload thema';
$GLOBALS['__l10n']['Blogroll'] = 'Blogs';
$GLOBALS['__l10n']['save'] = 'opslaan';
$GLOBALS['__l10n']['Link title:'] = 'titel';
$GLOBALS['__l10n']['select this comment'] = 'Verwijder dit blog';
$GLOBALS['__l10n']['select this trackback'] = 'Accepteer trackbacks';
$GLOBALS['__l10n']['Personal options has been successfully updated.'] = 'Blog succesvol geupdate.';
$GLOBALS['__l10n']['Favorites have been successfully added.'] = 'Blog succesvol gemaakt.';
$GLOBALS['__l10n']['Favorites have been successfully updated.'] = 'Blog succesvol geupdate.';
$GLOBALS['__l10n']['Favorites have been successfully removed.'] = 'Blog succesvol gemaakt.';
$GLOBALS['__l10n']['Default favorites have been successfully updated.'] = 'Blog succesvol geupdate.';
$GLOBALS['__l10n']['Delete selected favorites'] = 'verwijder geselecteerd thema';
$GLOBALS['__l10n']['superadmin'] = 'Super administrator';
?>
